@@ -39,15 +39,16 @@ __all__ = (
     "enable_logging",
     "groups",
     "OAUTH_CHECK_URL",
+    "process_path",
     "reports",
     "UPDATE_CHECK_URL",
 )
 
 __productname__ = "analytix"
-__version__ = "4.1.4"
+__version__ = "4.1.5"
 __description__ = "A simple yet powerful wrapper for the YouTube Analytics API."
 __url__ = "https://github.com/parafoxia/analytix"
-__docs__ = "https://parafoxia.github.io/analytix/"
+__docs__ = "https://parafoxia.github.io/analytix"
 __author__ = "Ethan Henderson"
 __author_email__ = "ethan.henderson.1998@gmail.com"
 __license__ = "BSD 3-Clause 'New' or 'Revised' License"
@@ -68,5 +69,5 @@ UPDATE_CHECK_URL = "https://pypi.org/pypi/analytix/json"
 
 from . import groups, reports
 from .client import AsyncBaseClient, AsyncClient, Client
-from .utils import *
+from .utils import can_use, process_path
 from .ux import enable_logging
